@@ -1,6 +1,7 @@
-from deep_utils.utils.resize_utils.main_resize import resize
-from .cv2_config import CV2Config
 from deep_utils.utils.lib_utils.lib_decorators import get_from_config
+from deep_utils.utils.resize_utils.main_resize import resize
+
+from .cv2_config import CV2Config
 
 
 class CV2Main:
@@ -9,15 +10,17 @@ class CV2Main:
         self.config = config
 
     @get_from_config
-    def forward(self,
-                image,
-                resize_size=None,
-                img_scale_factor=None,
-                img_mean=None,
-                swap_rgb=None,
-                resize_mode=None
-                ):
+    def forward(
+        self,
+        image,
+        resize_size=None,
+        img_scale_factor=None,
+        img_mean=None,
+        swap_rgb=None,
+        resize_mode=None,
+    ):
         import cv2
+
         image_len = len(image.shape)
         resize_img = resize(image, resize_size, mode=resize_mode)
         if image_len == 3:
@@ -26,7 +29,7 @@ class CV2Main:
                 scalefactor=img_scale_factor,
                 size=resize_size,
                 mean=img_mean,
-                swapRB=swap_rgb
+                swapRB=swap_rgb,
             )
         elif image_len == 4:
             blobs = cv2.dnn.blobFromImages(
@@ -34,7 +37,7 @@ class CV2Main:
                 scalefactor=img_scale_factor,
                 size=resize_size,
                 mean=img_mean,
-                swapRB=swap_rgb
+                swapRB=swap_rgb,
             )
         else:
             raise Exception("The shape of the input image is not valid.")
