@@ -1,8 +1,6 @@
 from .arg_parser import easy_argparse
 from .hyper_parameters import KeyValStruct, YamlConfig, yaml_config2yaml_file
-from .json_utils import dump_json, load_json
 from .seeds import tf_set_seed
 from .shuffle_utils import shuffle_group, shuffle_group_torch
 from .str_utils import color_str
-from .variable_utils import get_counter_name
 from .yaml_utils import dump_yaml, load_yaml, yaml_post_process
